package com.kakao.sdk.sample.common;

import android.util.SparseArray;
import android.util.SparseIntArray;
import android.view.View;
import androidx.databinding.DataBinderMapper;
import androidx.databinding.DataBindingComponent;
import androidx.databinding.ViewDataBinding;
import com.kakao.sdk.sample.common.databinding.FragmentDebugBindingImpl;
import com.kakao.sdk.sample.common.databinding.ItemApiBindingImpl;
import com.kakao.sdk.sample.common.databinding.ItemFriendBindingImpl;
import com.kakao.sdk.sample.common.databinding.ItemHeaderBindingImpl;
import java.lang.IllegalArgumentException;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.RuntimeException;
import java.lang.String;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class DataBinderMapperImpl extends DataBinderMapper {
  private static final int LAYOUT_FRAGMENTDEBUG = 1;

  private static final int LAYOUT_ITEMAPI = 2;

  private static final int LAYOUT_ITEMFRIEND = 3;

  private static final int LAYOUT_ITEMHEADER = 4;

  private static final SparseIntArray INTERNAL_LAYOUT_ID_LOOKUP = new SparseIntArray(4);

  static {
    INTERNAL_LAYOUT_ID_LOOKUP.put(com.kakao.sdk.sample.common.R.layout.fragment_debug, LAYOUT_FRAGMENTDEBUG);
    INTERNAL_LAYOUT_ID_LOOKUP.put(com.kakao.sdk.sample.common.R.layout.item_api, LAYOUT_ITEMAPI);
    INTERNAL_LAYOUT_ID_LOOKUP.put(com.kakao.sdk.sample.common.R.layout.item_friend, LAYOUT_ITEMFRIEND);
    INTERNAL_LAYOUT_ID_LOOKUP.put(com.kakao.sdk.sample.common.R.layout.item_header, LAYOUT_ITEMHEADER);
  }

  @Override
  public ViewDataBinding getDataBinder(DataBindingComponent component, View view, int layoutId) {
    int localizedLayoutId = INTERNAL_LAYOUT_ID_LOOKUP.get(layoutId);
    if(localizedLayoutId > 0) {
      final Object tag = view.getTag();
      if(tag == null) {
        throw new RuntimeException("view must have a tag");
      }
      switch(localizedLayoutId) {
        case  LAYOUT_FRAGMENTDEBUG: {
          if ("layout/fragment_debug_0".equals(tag)) {
            return new FragmentDebugBindingImpl(component, view);
          }
          throw new IllegalArgumentException("The tag for fragment_debug is invalid. Received: " + tag);
        }
        case  LAYOUT_ITEMAPI: {
          if ("layout/item_api_0".equals(tag)) {
            return new ItemApiBindingImpl(component, view);
          }
          throw new IllegalArgumentException("The tag for item_api is invalid. Received: " + tag);
        }
        case  LAYOUT_ITEMFRIEND: {
          if ("layout/item_friend_0".equals(tag)) {
            return new ItemFriendBindingImpl(component, view);
          }
          throw new IllegalArgumentException("The tag for item_friend is invalid. Received: " + tag);
        }
        case  LAYOUT_ITEMHEADER: {
          if ("layout/item_header_0".equals(tag)) {
            return new ItemHeaderBindingImpl(component, view);
          }
          throw new IllegalArgumentException("The tag for item_header is invalid. Received: " + tag);
        }
      }
    }
    return null;
  }

  @Override
  public ViewDataBinding getDataBinder(DataBindingComponent component, View[] views, int layoutId) {
    if(views == null || views.length == 0) {
      return null;
    }
    int localizedLayoutId = INTERNAL_LAYOUT_ID_LOOKUP.get(layoutId);
    if(localizedLayoutId > 0) {
      final Object tag = views[0].getTag();
      if(tag == null) {
        throw new RuntimeException("view must have a tag");
      }
      switch(localizedLayoutId) {
      }
    }
    return null;
  }

  @Override
  public int getLayoutId(String tag) {
    if (tag == null) {
      return 0;
    }
    Integer tmpVal = InnerLayoutIdLookup.sKeys.get(tag);
    return tmpVal == null ? 0 : tmpVal;
  }

  @Override
  public String convertBrIdToString(int localId) {
    String tmpVal = InnerBrLookup.sKeys.get(localId);
    return tmpVal;
  }

  @Override
  public List<DataBinderMapper> collectDependencies() {
    ArrayList<DataBinderMapper> result = new ArrayList<DataBinderMapper>(1);
    result.add(new androidx.databinding.library.baseAdapters.DataBinderMapperImpl());
    return result;
  }

  private static class InnerBrLookup {
    static final SparseArray<String> sKeys = new SparseArray<String>(5);

    static {
      sKeys.put(0, "_all");
      sKeys.put(1, "api_label");
      sKeys.put(2, "header_title");
      sKeys.put(3, "item");
      sKeys.put(4, "logs");
    }
  }

  private static class InnerLayoutIdLookup {
    static final HashMap<String, Integer> sKeys = new HashMap<String, Integer>(4);

    static {
      sKeys.put("layout/fragment_debug_0", com.kakao.sdk.sample.common.R.layout.fragment_debug);
      sKeys.put("layout/item_api_0", com.kakao.sdk.sample.common.R.layout.item_api);
      sKeys.put("layout/item_friend_0", com.kakao.sdk.sample.common.R.layout.item_friend);
      sKeys.put("layout/item_header_0", com.kakao.sdk.sample.common.R.layout.item_header);
    }
  }
}
